.. highlight:: shell

============
Installation
============

At the command line::

    $ pip install bottleship

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv bottleship
    $ pip install bottleship
